@@ -23,7 +23,7 @@
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
  *****************************************************************************/
 
-#include <klocale.h>
+//#include <klocale.h>
 //#include <kdebug.h>
 //#include <ostream.h>
 #include "adif.h"
@@ -463,3 +463,74 @@ QString Adif::number2Continent(int tcont){
 
 }
 
+int Adif::entity2AdifNumber(const QString& tPref){ // returns the ADIF number of an entity
+	if (tPref == "VE"){
+		return 1;
+	}else if (tPref == "ABU AIL IS"){
+		return 2;
+	}else if (tPref == "YA"){
+		return 3;
+	}else if (tPref == "3B6"){
+		return 4;
+	}else if (tPref == "OH0"){
+		return 5;
+	}else if (tPref == "KL"){
+		return 6;
+	}else if (tPref == "ZA"){
+		return 7;
+	}else if (tPref == "ALDABRA"){
+		return 8;
+	}else if (tPref == "KH8"){
+		return 9;
+	}else if (tPref == "FT5Z"){
+		return 10;
+	}else if (tPref == "VU4"){
+		return 11;
+	}else if (tPref == "VP2E"){
+		return 12;
+	}else if (tPref == "CE9"){
+		return 13;
+	}else if (tPref == "EK"){
+		return 14;
+	}else if (tPref == "UA9"){
+		return 15;
+	}else if (tPref == "ZL9"){
+		return 16;
+	}else if (tPref == "YV0"){
+		return 17;
+	}else if (tPref == "4J"){
+		return 18;
+	}else if (tPref == "BAJO NUEVO"){
+		return 19;
+	}else if (tPref == "KH1"){
+		return 20;
+	}else if (tPref == "EA6"){
+		return 21;
+	}else if (tPref == "T8"){
+		return 22;
+	}else if (tPref == "BLENHEIM REEF"){
+		return 23;
+	}else if (tPref == "3Y/B"){
+		return 24;
+	}else if (tPref == "BRITISH N. BORNEO"){
+		return 25;
+	}else if (tPref == "BRITISH SOMALI"){
+		return 26;
+	}else if (tPref == "EU"){
+		return 27;
+	}else if (tPref == "CANAL ZONE"){
+		return 28;
+	}else if (tPref == "EA8"){
+		return 29;
+	}else if (tPref == "CELEBE/MOLUCCA IS"){
+		return 30;
+	}else if (tPref == "T31"){
+		return 31;
+	}else if (tPref == "EA9"){
+		return 32;
+
+	}else{
+		return -1;
+	}
+
+}
\ No newline at end of file
