@@ -36,7 +36,7 @@
 #include <klineedit.h>
 #include <kcombobox.h>
 #include "klogui.h"
-//#include <qlistview.h>
+#include <qlistview.h>
 #include <klistview.h>
 #include <qfile.h>
 #include <qdatetime.h>
@@ -48,7 +48,7 @@
 #include <qpoint.h>
 #include <qlcdnumber.h>
 #include <kglobal.h>
-#include <klocale.h>
+//#include <klocale.h>
 #include <kpushbutton.h>
 #include <qcheckbox.h>
 #include <qmessagebox.h>
@@ -93,6 +93,7 @@
 #include "awards.h"
 #include "award.h"
 #include "reference.h"
+//#include <Qt3Support>
 //#include "ostream.h"
 
 // BANDS 9 {10/12/15/17/20/30/40/80/160}
@@ -107,69 +108,70 @@
 
 class Klog : public klogui {
 //f  friend class QslNeeded;
-  friend class dxClusterSpotItem;
-  Q_OBJECT
-  public:
-    /** construtor */
-    Klog(QWidget* parent=0, const char *name=0);
-    /** destructor */
-    ~Klog();
-    //Qso qso;
-    
-    World world;
+	friend class dxClusterSpotItem;
+	Q_OBJECT
+	public:
+	/** construtor */
+	Klog(QWidget* parent=0, const char *name=0);
+	/** destructor */
+	~Klog();
+	//Qso qso;
+
+	World world;
 //    Entity entity;
 
-    typedef QValueList<Qso> LogBook;
-    
-    LogBook logbook;
-    LogBook oLogbook; //Ordered logbook (by date) (exit from orderLog)
-    
-  //public:
-  bool haveWorld();
-  
-  public slots:
-  void slotUpdateTime();
-  void slotQSLRec();
-  void slotQSLSent();
-  void slotQSLRecSent();  
-  void slotQsoDelete();
-//  slotDeleteQso();
-  void slotCancelSearchButton();
-  void slotSearchButton();
-  void slotQrzChanged();
-  void slotOkBtn();
-  void slotClearBtn();
-  void clearEntityBox();
-  void slotQslSentBoxChanged();
-  void slotQslRecvBoxChanged();
-  void slotQSLcomboBoxChanged();
+	typedef QValueList<Qso> LogBook;
+
+	LogBook logbook;
+	LogBook oLogbook; //Ordered logbook (by date) (exit from orderLog)
+
+	//public:
+	bool haveWorld();
+
+	public slots:
+	void slotUpdateTime();
+	void slotQSLRec();
+	void slotQSLSent();
+	void slotQSLRecSent();
+	void slotQsoDelete();
+	//  slotDeleteQso();
+	void slotCancelSearchButton();
+	void slotSearchButton();
+	void slotQrzChanged();
+	void slotOkBtn();
+	void slotClearBtn();
+	void clearEntityBox();
+	void slotQslSentBoxChanged();
+	void slotQslRecvBoxChanged();
+	void slotQSLcomboBoxChanged();
 	void slotLocalAwardChanged();
-  void slotPreferences();  
-  void fileNew();
-  void fileSave();
-  void fileSaveAs();
-  void filePrint();
-  void slothamlibUpdateFrequency();
-    
-  void adifFileSave();
-//  void adifSaveAs(const QString& tfileName);
-  void adifReadLog(const QString& tfileName);
-  int getProgresStepForDialog(int totalSteps);
-//  void newAdifReadLog (const QString& tfileName);
-  void tlfReadLog(const QString& tfileName);  
-  void fileOpen();  
-  void fileExit();
-  void helpAbout();
-  void readQso(); //Just read the values an fill the qso
-  void modifyQso(); // Modify an existing QSO with the data on the boxes
-  void slotQsoSelectedForEdit(QListViewItem* item);//Puts the QSO in the edit box
-  void slotQsoSearchSelectedForEdit( QListViewItem * item); //Puts the QSO in the edit box
-  void slotQsoSelected (QListViewItem* item); // Just to see qso data
-  void slotQsoRightButtonFromLog(QListViewItem * item, const QPoint &p);
-  void slotQsoRightButtonFromSearch(QListViewItem * item, const QPoint &p);
-  void slotModifyBtn();
-  void showLogList();   // Shows the log in the botton widget
-  void showMenuRightButton(int qqso, const QPoint &p); //This is called from  slotQsoRightButton and show the actions menu
+	void slotSearchQSO2QSL(); // Shows in the search box QSO from which we need the QSL and we have not sent it.
+	void slotPreferences();
+	void fileNew();
+	void fileSave();
+	void fileSaveAs();
+	void filePrint();
+	void slothamlibUpdateFrequency();
+
+	void adifFileSave();
+	//  void adifSaveAs(const QString& tfileName);
+	void adifReadLog(const QString& tfileName);
+	int getProgresStepForDialog(int totalSteps);
+	//  void newAdifReadLog (const QString& tfileName);
+	void tlfReadLog(const QString& tfileName);
+	void fileOpen();
+	void fileExit();
+	void helpAbout();
+	void readQso(); //Just read the values an fill the qso
+	void modifyQso(); // Modify an existing QSO with the data on the boxes
+	void slotQsoSelectedForEdit(QListViewItem* item);//Puts the QSO in the edit box
+	void slotQsoSearchSelectedForEdit( QListViewItem * item); //Puts the QSO in the edit box
+	void slotQsoSelected (QListViewItem* item); // Just to see qso data
+	void slotQsoRightButtonFromLog(QListViewItem * item, const QPoint &p);
+	void slotQsoRightButtonFromSearch(QListViewItem * item, const QPoint &p);
+	void slotModifyBtn();
+	void showLogList();   // Shows the log in the botton widget
+	void showMenuRightButton(int qqso, const QPoint &p); //This is called from  slotQsoRightButton and show the actions menu
 
 // Printing modules
 //  void slotPrint();
@@ -186,7 +188,8 @@ class Klog : public klogui {
   void accept();
 
   private slots:
-    void slotLocatorChanged();
+	void slotLocatorChanged();
+	void slotMyLocatorChanged();
     void slotClusterCloseConnection();
     void slotClusterSendToServer();
     void slotClusterSocketReadyRead();
@@ -202,15 +205,15 @@ class Klog : public klogui {
     void slotKlogSetup();
     void slotBugReport();
     void slotModeChanged (int i);
-    void slotBandChanged ();    
+    void slotBandChanged ();
 
   private:
-	
+
     Qso qso;
     Qso previousQso;       // This and workedCall is to check if a call has been previously
     WorkedCalls workedCall;// worked and it is posible to reuse the data.
     bool completeWithPrevious;	// Configuration parameter
-    
+
     typedef QValueList<Reference> References; // The list of references of the current award.
     References references;		// The references of the current award.
 
@@ -235,11 +238,12 @@ class Klog : public klogui {
 	void prepareAwardBox (const int tenti);
 	bool checkIfValidDXCluster(const QString &tdxcluster); // Is a valid URL? 
 //    void slotQslNeededCheck();
-    void setMyQrz(const QString &tqrz);
-    QString getMyQrz() const;
-    void setMyLocator(const QString &tlocator);
-    QString getMyLocator() const;
-    void showWhere(const int enti);
+	void setMyQrz(const QString &tqrz);
+	QString getMyQrz() const;
+	void setMyLocator(const QString &tlocator);
+	QString getMyLocator() const;
+	void showWhere(const int enti);
+	QString getThisQSODXLocator ();
     int needToWorkFromCluster(const QString &tqrz, const int tband); // 0 confirmed, 1 worked, 2 new one, -1 error
 //    QColor stateColor(const QString &tqrz, const int tband);    
     void showAwardsNumbers(); // Shows how many worked, confirmed, ...
@@ -255,7 +259,7 @@ class Klog : public klogui {
     void getAllTheCallsFromLog();
     QString getNumberString(const int intNumber);
     int getEntityFromCall(); // Just read the call from the QRZ box and returns the entity number
-    
+
     void prepareAwardComboBox(const int tenti);
     QString checkExtension(QString extension); // To check the extension of the file // TNX Kike
 
@@ -265,14 +269,16 @@ class Klog : public klogui {
 //    int band2Num(const QString &tband);
 
   //  Qso qso;
-    bool showProgressDialog;
-    QColor ledColor;
-    Locator locator;
+	bool showProgressDialog;
+	QColor ledColor;
+	Locator locator;
+	QString myLocatorTemp;  // To manage temp locators and distances
     QString dxLocator;
     QString myQrz;
     QString myLocator;
     QString klogDir;
-    QString logFileName;
+	QString logFileNameToOpen;
+	QString logFileNameToSave;
     QString aux;
     QString operatorStringAux;
     QString textStringAux;
@@ -299,31 +305,32 @@ class Klog : public klogui {
     int sTxValue;
     int sRxValue;
 
-    
-    int band;   // Band used in the QSO
-    int imode;
-    QString power;  // Power used for the QSO (in your side)
-    QStringList fields; // Auxiliary variable to splir log/formated strings
-    int i, j;
-    int kk;     // This is just for intra-fuction use 
-    int itemPos; // for modifying
-    int enti;   //Just for entity name show
-    int entiBak;
-    int callLen;  // The call's lenght
-    int callLenPrev;  // The previous call's lenght to detect if deleting
-    int callLenFound;
-    int beam; // the beam in degrees DELETE
-    int distance;     // Distance between the two stations in the QSO
-    bool lastDelete;  // Last key pressed is delete?
-    bool callFound;   // Boolean to show if the call has been found
-    bool modify;
-    bool prefixFound;
-    bool dirExist;
-    bool needToSave;
-    bool actionSent;
-    bool actionRec;
-    bool timeInUTC;   // Time in UTC or LocalTime
-    bool realTimeLog; // The clock will be in real time or stopped to add previous QSOs
+
+	int band;   // Band used in the QSO
+	int imode;
+	QString power;  // Power used for the QSO (in your side)
+	QStringList fields; // Auxiliary variable to splir log/formated strings
+	int i, j;
+	int kk;     // This is just for intra-fuction use 
+	int itemPos; // for modifying
+	int enti;   //Just for entity name show
+	int entiBak;
+	int callLen;  // The call's lenght
+	int callLenPrev;  // The previous call's lenght to detect if deleting
+	int callLenFound;
+	int beam; // the beam in degrees DELETE
+	int distance;     // Distance between the two stations in the QSO
+	bool lastDelete;  // Last key pressed is delete?
+	bool callFound;   // Boolean to show if the call has been found
+	bool modify;
+	bool searching2QSL; 
+	bool prefixFound;
+	bool dirExist;
+	bool needToSave;
+	bool actionSent;
+	bool actionRec;
+	bool timeInUTC;   // Time in UTC or LocalTime
+	bool realTimeLog; // The clock will be in real time or stopped to add previous QSOs
 //    bool justOneTime; //  For slotQslRec to avoid twice confirmed--
     bool wasConfirmed; // For the same purporse as above.
 	bool openLastByDefault;
@@ -389,7 +396,7 @@ class Klog : public klogui {
     double hamlibFreq;
     int bauds;
     int rignameNumber;
-    int strength;
+    //int strength;
     int hamlibInterval;
     QString serialPort;
     QTimer *hamlibtimer;
