@@ -39,6 +39,7 @@ Qso::Qso(const QString& tqrz, int tnumb, QString& tmode){
   qslRecc = 'N';      // QSL_RCVD Y, N, R, I
   qslSenc = 'N';      // QSL_SENT Y, N, R, I
   localAward = ""; // LocalAward has to be "null" if empty.
+myGridSquare = "NULL";
 
 }
 
@@ -55,6 +56,7 @@ Qso::Qso(const int tnumb, const QString& tqrz, const int trstrx, const int trstt
     power = tpower;
   qslRecc = 'N';      // QSL_RCVD Y, N, R, I
   qslSenc = 'N';      // QSL_SENT Y, N, R, I
+myGridSquare = "NULL";
 }
 
 
@@ -72,6 +74,7 @@ Qso::Qso(const int tnumb, const QDateTime tdateTime, const QString& tqrz, const
   comment = tcomment;
   qslRecc = 'N';      // QSL_RCVD Y, N, R, I
   qslSenc = 'N';      // QSL_SENT Y, N, R, I
+myGridSquare = "NULL";
 
 }      
 
@@ -90,6 +93,7 @@ Qso::Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, cons
   comment = tcomment;
   qslRecc = 'N';      // QSL_RCVD Y, N, R, I
   qslSenc = 'N';      // QSL_SENT Y, N, R, I
+myGridSquare = "NULL";
 }
 
 
@@ -246,6 +250,14 @@ QString Qso::getLocator() const {
   return gridSquare;
 }
 
+void Qso::setMyLocator(const QString &tgridSquare ){
+    myGridSquare = tgridSquare;
+}
+
+QString Qso::getMyLocator() const {
+  return myGridSquare;
+}
+
 void Qso::setIota(const QString &tiota){
 // TODO:
 // It is necessary to check the received QString to  allow only valid IOTA
