@@ -88,13 +88,13 @@ public:
 
   void setQslRecDateOn(QDate tdate);
   QDate getQslRecDate() const;
-  
+
   void QslRec(const QChar& qslState);
   QChar isQslRec();
 
   bool gotTheQSL();  // Ask if i have his QSL
   bool sentTheQSL(); // Did i sent my QSL?
-  
+
   void setComment(const QString &tcomment);
   QString getComment()const;  
 
@@ -110,6 +110,9 @@ public:
   void setLocator(const QString &tqrz);
   QString getLocator() const;
 
+  void setMyLocator(const QString &tqrz);
+  QString getMyLocator() const;
+
   void setIota(const QString &tiota);
   QString getIota() const;
   QString getIotaContinent() const;
@@ -118,11 +121,10 @@ public:
   void setLocalAward(const QString &taward);
   QString getLocalAward() const;
 
-  
+
   void setLocalAwardNumber(int taward); // Those two functions are just for awards reference
   int getLocalAwardNumber() const;      // management
-	
-  
+
   void setName(const QString &tname);
   QString getName() const;  
 
@@ -134,9 +136,8 @@ public:
 
  void setPropMode(const QString &tprop_mode);
  QString getPropMode() const;
-  
+
   void clearQso();
-  
 
 private:
   QString qrz;        // CALL
@@ -159,7 +160,8 @@ private:
   QString qslInfo;    // ADDRESS /QSLMSG
   QString manager;
   int qslHow;         // How is the qsl to be send
-  QString gridSquare; // GRIDSQUARE
+  QString gridSquare; // GRIDSQUARE (the DX's one)
+	QString myGridSquare; //(My grid)
   QString iota;       // IOTA
   QString localAward;	// Each Entity may have a local award reference (TPEA, WAS, ...)
   int localAwardNumber; // Just a help for award references management but not saved into the log
