@@ -30,31 +30,32 @@
 
 
 
-Setup::Setup(QWidget *parent, const char *name) :  setupui(parent, name)
-{
-  klogDir = QDir::homeDirPath()+"/.klog";  // We create the ~/.klog for the logs
-  if (!QDir::setCurrent ( klogDir )){
-    QDir d1(klogDir);
-    dirExist = d1.mkdir(klogDir, true);
-  }
-  dirExist = QDir::setCurrent ( klogDir ) ;
-  fileName = "";
+Setup::Setup(QWidget *parent, const char *name) :  setupui(parent, name){
+	klogDir = QDir::homeDirPath()+"/.klog";  // We create the ~/.klog for the logs
+	if (!QDir::setCurrent ( klogDir )){
+		QDir d1(klogDir);
+		dirExist = d1.mkdir(klogDir, true);
+	}
+	dirExist = QDir::setCurrent ( klogDir ) ;
+	fileName = "";
   ///////////////////////////////////////////////////////////////////////////////
   // Modifications by kike
   // 25-03-2004
   //////////////////////////////////////////////////////////////////////////////
   // Fill the rig combo
-  setRig();
+	setRig();
   //////////////////////////////////////////////////////////////////////////////
   // End of modifications
   /////////////////////////////////////////////////////////////////////////////
 
-  readConf();
-  
-  slotOpenFileButtonClicked();
+	readConf();
+
+	slotOpenFileButtonClicked();
 	awardToDelete = -1;
+
 }
 
+
 Setup::~Setup()
 {
 }
