@@ -32,7 +32,7 @@ World::World(){
      int cqzone = 0; 
      int ituzone = 0;
      QString finalPrefix;
-     
+
 
   created = false;
   number = 0;
@@ -50,10 +50,7 @@ World::World(){
       */
 }
 // I have no idea where cty.dat is!!!
-  
-      
-      
-      
+
   if ( file.open( IO_ReadOnly ) ) {
     QTextStream stream( &file );
     QString line;
@@ -88,7 +85,7 @@ World::World(){
      cqzone = fields[1].toInt();
      ituzone = fields[2].toInt();
      finalPrefix = prefs[n];
-     
+
      // Here I have the prefix but also the (zone)[zone] when special zone is added 
      // HERE IS NECESARY TO CHECK IF THIS IS A SPECIAL PREFIX IN A DIFFERENT ZONE (CQ OR ITU)
         if (prefs[n].contains('(')>0 ){ // The prefix contains special CQzone
@@ -105,11 +102,13 @@ World::World(){
         if (prefs[n].contains('(') ){
           finalPrefix = prefs[n].left(prefs[n].find('('));      
         }
-     
-     
-     World::cqMap[finalPrefix] = cqzone;
-            World::ituMap[finalPrefix] = ituzone;    
-            World::map[finalPrefix] = entity;
+
+
+	World::cqMap[finalPrefix] = cqzone;
+	World::ituMap[finalPrefix] = ituzone;
+	World::map[finalPrefix] = entity;
+//	World::cqMapi[cqzone] = number;
+//	World::ituMapi[ituzone] = number;
           //entity.addPrefix(prefs[n].latin1());
           n++;
         }//
@@ -207,6 +206,10 @@ int World::findEntity(const QString string){
 			//   prefix = prefixa;
 			return i;
 		}
+		if (prefixa.endsWith("/")||prefixa.endsWith("\\")){ // We look for calls ending in slash "/" or "\"
+			
+			prefixa.remove(prefixa.length()-1,1);
+		}
 		if (prefixa.contains('/')){
 			ij = prefixa.find('/');
 			if ( (abs)(ij) < (abs)((prefixa.length())- ij)  ) { //Like in F/EA4TV
@@ -335,31 +338,33 @@ int World::findEntity(const QString string){
 						prefixa = "4K1ZI";
 						return giveEnt(prefixa);
 					}
-     
-            if ( (prefixa.upper().endsWith("/N")) && (prefixa.upper().startsWith("ZK1" )) ){
-            // This is North Cook Is.
-  prefixa = "ZK1AAH";
-  return giveEnt(prefixa);
-            }         
-     
-            prefixab = prefixa.right(prefixa.length()-(ij+1));
-        }else{  // It is a EA4TV/P or EA4TV/QRP    
-     // Peter I, is a special "/P" station... so we need to check it.
-     if ( (prefixa.upper().endsWith("/P")) && (prefixa.upper().startsWith("3Y" )) ){
-            // This is Peter I
-          prefixa = "3Y0PI";
-          return giveEnt(prefixa);
-            }     
-            // Marquesas, is a special "/M" station... so we need to check it.     
-            if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("FO" )) ){
-            // This is Marquesas Is.
-  prefixa = "FO/DL1AWI";
-  return giveEnt(prefixa);
-            }
-     
-     prefixab =  prefixa.left(ij);           
-        }
-        qrz2 = prefixab;
+					if ( (prefixa.upper().endsWith("/N")) && (prefixa.upper().startsWith("ZK1" )) ){
+					// This is North Cook Is.
+						prefixa = "ZK1AAH";
+						return giveEnt(prefixa);
+					}
+            				prefixab = prefixa.right(prefixa.length()-(ij+1));
+				}else{  // It is a EA4TV/P or EA4TV/QRP    
+					// Peter I, is a special "/P" station... so we need to check it.
+					if ( (prefixa.upper().endsWith("/P")) && (prefixa.upper().startsWith("3Y" )) ){
+						// This is Peter I
+						prefixa = "3Y0PI";
+						return giveEnt(prefixa);
+					}
+					// Marquesas, is a special "/M" station... so we need to check it.     
+					if ( (prefixa.upper().endsWith("/M")) && (prefixa.upper().startsWith("FO" )) ){
+					// This is Marquesas Is.
+						prefixa = "FO/DL1AWI";
+						return giveEnt(prefixa);
+					}
+					prefixab =  prefixa.left(ij);
+					if ((prefixa.upper().endsWith("/M"))||(prefixa.upper().endsWith("/MM"))){// /M and /MM does not count as DXCC
+						return -1;
+					}else{// Normal /p, /m, ... prefix
+
+					}
+				}
+			qrz2 = prefixab;
       }
     }else{
       ij = prefixa.find("\\");
@@ -520,13 +525,13 @@ bool World::isSpecial(const QString &tpfx){  // This functions returns true if E
       return it.data().getNumb();
   }
   else
-    return 0;    
-}    
+    return 0;
+}
 
 int World::getItuz(){  
     if (prefix=="NULL") // We are calling this function just after start KLog
  return 0;
-    
+
 //  qrz = prefix;
   itITU = ituMap.begin();
   itITU = ituMap.find(prefix);
@@ -534,9 +539,27 @@ int World::getItuz(){
       return itITU.data();
   }
   else
-    return 0;        
+    return 0;
 }
 
+
+/*
+int World::getItuz(){  
+    if (tenti<=0) // We are calling this function just after start KLog
+ return 0;
+
+//  qrz = prefix;
+  itITU = ituMap.begin();
+  itITU = ituMap.find(prefix);
+  if (ituMap.find(prefix) != ituMap.end()){
+      return itITU.data();
+  }
+  else
+    return 0;
+}
+
+*/
+
   //EntityZMap cqMap, ituMap;
   //EntityNMap::Iterator itCQ, itITU;  
   
